#!/bin/sh

######################################################################
# Verify new configuration
# nagios-New.cfg specifies ~/Auto/New instead of ~/Auto/Current

NAGIOSBIN=/home/nagios/bin
NAGIOSCFG=/home/nagios/etc/nagios-TestNew.cfg
CONFIGDIR=/home/nagios/etc/conf/Auto

${NAGIOSBIN}/nagios -v $NAGIOSCFG \
      && {

      # Install new files because Nagios validated new config
      MYDATE=`date +"%Y%m%d-%H%M%S"`
      
      # Has the configuration changed? If not, don't bother.
      diff --exclude=\*.log -r ${CONFIGDIR}/Current ${CONFIGDIR}/New \
	  && {
	  
	  rm -rf ${CONFIGDIR}/New
	  mkdir ${CONFIGDIR}/New
	  echo "No changes in configuration detected."
	  exit 0
	  }

      # Archive our current config
      mv ${CONFIGDIR}/Current ${CONFIGDIR}/Archive/$MYDATE

      # Move in the new one
      mv ${CONFIGDIR}/New ${CONFIGDIR}/Current
      mkdir ${CONFIGDIR}/New
      
      # Restart nagios
      echo "Restarting Nagios..."
      kill -HUP `cat ~/var/nagios.lock`

      # Mail off a diff of what changed to the nagios admin
      diff -x KSC_NACE_Query.log -NaruBr ${CONFIGDIR}/Archive/$MYDATE/ ${CONFIGDIR}/Current/ \
              | mail -s "`basename $0`: Update Successful $MYDATE" nagios

} || {

      MYDATE=`date +"%Y%m%d-%H%M%S"`

      # Update failed, rollback changes.
      
      mv ${CONFIGDIR}/New ${CONFIGDIR}/Bad/$MYDATE
      mkdir ${CONFIGDIR}/New

      # Mail a diff to the nagios admin to alert them to the problem.
      diff -x KSC_NACE_Query.log -NaruBr ${CONFIGDIR}/Current/ ${CONFIGDIR}/Bad/$MYDATE/ \
              | mail -s "`basename $0`: Update Failed $MYDATE" nagios
      
}
